summaryrefslogtreecommitdiff
path: root/engine/items/tms.asm
diff options
context:
space:
mode:
authoryenatch <yenatch@gmail.com>2014-05-26 14:04:56 -0700
committeryenatch <yenatch@gmail.com>2014-05-26 22:04:39 -0700
commit40c17c906b2b3f65b3b04b1933b90238a7ac5566 (patch)
tree6de26c959808d5a792b692f2300c33557c1dbfab /engine/items/tms.asm
parent52ba96f5f4ec53450a0ff6257ea1040d09b7e537 (diff)
Remove most static wram addresses. Use labels instead.
For unknown addresses, use "w<address>". Label overleads are still an issue.
Diffstat (limited to 'engine/items/tms.asm')
-rwxr-xr-xengine/items/tms.asm14
1 files changed, 7 insertions, 7 deletions
diff --git a/engine/items/tms.asm b/engine/items/tms.asm
index 409a655b..53b338d6 100755
--- a/engine/items/tms.asm
+++ b/engine/items/tms.asm
@@ -1,11 +1,11 @@
; tests if mon [$cf91] can learn move [$d0e0]
TestMonMoveCompatibility: ; 1373e (4:773e)
- ld a, [$cf91]
- ld [$d0b5], a
+ ld a, [wcf91]
+ ld [wd0b5], a
call GetMonHeader
ld hl, W_MONHLEARNSET
push hl
- ld a, [$d0e0]
+ ld a, [wd0e0]
ld b, a
ld c, $0
ld hl, TechnicalMachines
@@ -21,17 +21,17 @@ TestMonMoveCompatibility: ; 1373e (4:773e)
ld a, $10 ; FlagActionPredef
jp Predef
; converts TM/HM number in $d11e into move number
; HMs start at 51
TMToMove: ; 13763 (4:7763)
- ld a, [$d11e]
+ ld a, [wd11e]
dec a
ld hl, TechnicalMachines
ld b, $0
ld c, a
add hl, bc
ld a, [hl]
- ld [$d11e], a
+ ld [wd11e], a
ret
INCLUDE "data/tms.asm"
@@ -1,11 +1,11 @@
-; tests if mon [$cf91] can learn move [$d0e0]
+; tests if mon [wcf91] can learn move [wd0e0]
TestMonMoveCompatibility: ; 1373e (4:773e)
@@ -21,17 +21,17 @@ TestMonMoveCompatibility: ; 1373e (4:773e)
ld a, $10 ; FlagActionPredef
jp Predef
-; converts TM/HM number in $d11e into move number
+; converts TM/HM number in wd11e into move number
; HMs start at 51
TMToMove: ; 13763 (4:7763)